@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import math
 
 from bokeh.core.properties import without_property_validation
@@ -17,11 +19,8 @@ from dask.utils import format_bytes
 from distributed.dashboard.components import DashboardComponent, add_periodic_callback
 from distributed.dashboard.components.scheduler import BOKEH_THEME, TICKS_1024, env
 from distributed.dashboard.utils import update
-from distributed.diagnostics import nvml
 from distributed.utils import log_errors
 
-NVML_ENABLED = nvml.device_get_count() > 0
-
 
 class GPUCurrentLoad(DashboardComponent):
     """How many tasks are on each worker"""
